summaryrefslogtreecommitdiffstats
path: root/branches/sca-java-1.x/modules/interface/src/main/java/org/apache/tuscany/sca/interfacedef/Operation.java
diff options
context:
space:
mode:
authorslaws <slaws@13f79535-47bb-0310-9956-ffa450edef68>2009-03-26 13:23:57 +0000
committerslaws <slaws@13f79535-47bb-0310-9956-ffa450edef68>2009-03-26 13:23:57 +0000
commitaef1e52d6377f18516371655c32125c68bac0cce (patch)
tree598aeb93747d119998df3f87b22eacb0125efaa3 /branches/sca-java-1.x/modules/interface/src/main/java/org/apache/tuscany/sca/interfacedef/Operation.java
parentde53364092d375a98144b29e85e09abc8842268e (diff)
TUSCANY-2931 - allow separate request and response wire formats in binding.jms. The tuscany binding.jms XSD has been extended to allow a response wireFormat element to be specified. The knock on effect of all this is that the Operation interface has been changed to allow input and output wrapper info to be held separately. Also Interface has some new operations. There are changes across the code base to take account of this interface change.
git-svn-id: http://svn.us.apache.org/repos/asf/tuscany@758625 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to '')
-rw-r--r--branches/sca-java-1.x/modules/interface/src/main/java/org/apache/tuscany/sca/interfacedef/Operation.java37
1 files changed, 29 insertions, 8 deletions
diff --git a/branches/sca-java-1.x/modules/interface/src/main/java/org/apache/tuscany/sca/interfacedef/Operation.java b/branches/sca-java-1.x/modules/interface/src/main/java/org/apache/tuscany/sca/interfacedef/Operation.java
index 4676e35f80..51b7645e57 100644
--- a/branches/sca-java-1.x/modules/interface/src/main/java/org/apache/tuscany/sca/interfacedef/Operation.java
+++ b/branches/sca-java-1.x/modules/interface/src/main/java/org/apache/tuscany/sca/interfacedef/Operation.java
@@ -132,26 +132,47 @@ public interface Operation extends Cloneable, PolicySetAttachPoint {
* Set the operation to be non-blocking
*/
void setNonBlocking(boolean nonBlocking);
+
+ /**
+ * @return the inputWrapperInfo
+ */
+ WrapperInfo getInputWrapper();
+
+ /**
+ * @param wrapperInfo the inputWrapperInfo to set
+ */
+ void setInputWrapper(WrapperInfo wrapperInfo);
/**
- * @return the wrapperInfo
+ * @return the outputWrapperInfo
*/
- WrapperInfo getWrapper();
+ WrapperInfo getOutputWrapper();
/**
* @param wrapperInfo the wrapperInfo to set
*/
- void setWrapper(WrapperInfo wrapperInfo);
+ // TODO - WI
+ void setOutputWrapper(WrapperInfo wrapperInfo);
/**
- * @return the wrapperStyle
+ * @return the inputWrapperStyle
+ */
+ boolean isInputWrapperStyle();
+
+ /**
+ * @param inputWrapperStyle the wrapperStyle to set
+ */
+ void setInputWrapperStyle(boolean wrapperStyle);
+
+ /**
+ * @return the outputWrapperStyle
*/
- boolean isWrapperStyle();
+ boolean isOutputWrapperStyle();
/**
* @param wrapperStyle the wrapperStyle to set
*/
- void setWrapperStyle(boolean wrapperStyle);
+ void setOutputWrapperStyle(boolean wrapperStyle);
/**
* @deprecated This should be the WrapperInfo.getDataBinding()
@@ -132,26 +132,47 @@ public interface Operation extends Cloneable, PolicySetAttachPoint {
/**
- * @param wrapperInfo the wrapperInfo to set
+ * @param wrapperInfo the outputWrapperInfo to set
*/
@@ -132,26 +132,47 @@ public interface Operation extends Cloneable, PolicySetAttachPoint {
/**
- * @param wrapperStyle the wrapperStyle to set
+ * @param outputWrapperStyle the wrapperStyle to set
*/